function [ ] = signal(opt, f, hD, Pdc)
% signal(opt, f, hD, Pdc)
%
% signal.m produces optical gain plots. Radiation pressure effect is
% included in the results. The unit is [W/m] or [1/m] you choose in setup.m
% file.

global rd

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
%%% Initial setting
  setup;
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
%%% Optical gain

  for pn = 1 : length(PN)
    h = figure(300 + pn);
    scrsz = get(0,'ScreenSize');
    figpos = get(h, 'Position');
    if figpos == [420   528   560   420]
      set(h, 'Position',[scrsz(3)/2-560/2 scrsz(4)*0.4 560 scrsz(4)*0.5])
    end

    if MeterUnitOn == 1
      % oTF: the same definition as Thomas's tool, i.e. raw optical gain is devided by flat shotnoise
      if isempty(findstr('IM', opt.probe(PN(pn)).name))
        if isempty(findstr('HD', opt.probe(PN(pn)).name))
          %for single demodulation, or DC readout      
          oTF(:, pn, :) = abs(hD(:, pn, :)) / sqrt(Phv * Pdc(pn) * qeff);
        else
          %for Homodyne detection
          oTF(:, pn, :) = abs(hD(:, pn, :)) / sqrt(Phv * (Pdc(pn)) * qeff); % wrong! Pdc should be summed by two separate HD PDs.
        end
      else
        %for DDM, since two PD noises are summed         
        oTF(:, pn, :) = abs(hD(:, pn, :)) / (sqrt(2 * Phv * Pdc(pn) * qeff));
      end
    else
      oTF(:, pn, :) = abs(hD(:, pn, :));
    end
    oTFp(:, pn, :) = angle(hD(:, pn, :)) * (180 / pi);

    subplot(2, 1, 1)
    oTFg = zeros(length(PN), length(f));
    for b = 1 : length(PN)
      oTFg(b, :) = oTF(:, pn, b);
    end
    loglog(f, oTFg)
    clear lg
    for b = 1 : length(PN)
      lg(b) = {strcat(char(NC(b)))};
    end
    legend(lg)
    title(['Optical gain at ' char(ND(pn))])
    if MeterUnitOn == 1
      ylabel('1/m')
    else
      ylabel('W/m')
    end
    grid on

    subplot(2, 1, 2)
    semilogx(f, [oTFp(:, pn, Lp), oTFp(:, pn, Lm), oTFp(:, pn, lp), oTFp(:, pn, lm), oTFp(:, pn, lsr)]);
    xlabel('Hz')
    ylabel('phase [deg]')
    v = axis;
    axis([v(1) v(2) -180 180])
    grid on

    h = gcf;
    for ns = 1 : length(ext)
      saveas(h, [rd '/' num2str(300 + pn) '_optgain_' char(NC(pn)) '.' char(ext(ns))]);
    end
  end